import type { Context } from "koa";

export function ParseQueryNumber(s: string[] | string | undefined): number | undefined {
	if (s === undefined) return undefined;
	if (typeof s === "object") return undefined;
	return Number.parseInt(s);
}
export function ParseQueryArray(s: string[] | string | undefined) {
	const input = s ?? [];
	const r = Array.isArray(input) ? input : [input];
	return r.map((x) => decodeURIComponent(x));
}
export function ParseQueryArgString(s: string[] | string | undefined) {
	if (typeof s === "object") return undefined;
	return s === undefined ? s : decodeURIComponent(s);
}
export function ParseQueryBoolean(s: string[] | string | undefined): [boolean, boolean | undefined] {
	let value: boolean | undefined;

	if (s === "true") {
		value = true;
	} else if (s === "false") {
		value = false;
	} else if (s === undefined) {
		value = undefined;
	} else return [false, undefined];
	return [true, value];
}

export function since_last_modified(ctx: Context, last_modified: Date): boolean {
	const con = ctx.get("If-Modified-Since");
	if (con === "") return false;
	const mdate = new Date(con);
	if (last_modified > mdate) return false;
	ctx.status = 304;
	return true;
}
